ChartPoint class

One measured point of a run: a metric under a ref, with its display unit (charts name the series metric@ref — one series per reference setup).

Constructors

ChartPoint(String metric, String ref, num value, [String unit = ''])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metric String
final
name String
no setter
ref String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit String
final
value num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited