MetricDef class
Display definition of one published metric.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Store/report key of the metric (identical to its scenario id).
final
- label → String
-
Published row label (methodology copy).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → String
-
Display unit: elements / ms / B.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited