noGolden property
bool
get
noGolden
True when this metric was measured but has no recorded golden yet.
Implementation
bool get noGolden => golden == null || limit == null;
True when this metric was measured but has no recorded golden yet.
bool get noGolden => golden == null || limit == null;