driver property
Driver file path, relative to the consumer root (NOT under lib/ — the
driver runs in the flutter_test context and returns flutter_test types).
Implementation
final String driver;
Driver file path, relative to the consumer root (NOT under lib/ — the
driver runs in the flutter_test context and returns flutter_test types).
final String driver;