chartsUrl property
URL of the consumer's trend-charts page (github-action-benchmark gh- pages); rendered as a link under the table when present.
Implementation
final String? chartsUrl;
URL of the consumer's trend-charts page (github-action-benchmark gh- pages); rendered as a link under the table when present.
final String? chartsUrl;