MetricsCardStyle class
Visual knobs of the card. Defaults reproduce hintful's original look, so a consumer that does not restyle keeps the published snapshot identical.
Constructors
- MetricsCardStyle({Color sceneBackground = const Color(0xFFE6ECF0), Color cardBackground = const Color(0xFFF4F7F9), Color tileBackground = Colors.white, Gradient headerGradient = const LinearGradient(colors: [Color(0xFF004D40), Color(0xFF26A69A)]), Color headerText = Colors.white, Color accent = const Color(0xFF00796B), Color labelColor = const Color(0xFF263238), Color subtitleColor = const Color(0xFF78909C)})
-
const
Properties
- accent → Color
-
final
- cardBackground → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerGradient → Gradient
-
final
- headerText → Color
-
final
- labelColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sceneBackground → Color
-
final
- subtitleColor → Color
-
final
- tileBackground → Color
-
Tile card fill (white).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited