FrameWindow class
A window of FrameTimings collected while a benchmark action ran.
Constructors
-
FrameWindow(List<
FrameTiming> timings)
Properties
- avgBuildUs → double
-
Average build phase per frame, µs.
no setter
- avgRasterUs → double
-
Average raster phase per frame, µs.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slowFrames → int
-
Frames whose build+raster exceeded the 60 Hz budget.
no setter
-
timings
→ List<
FrameTiming> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited